@@ -47,9 +47,12 @@ from data_science_helper.model import lgb_model as l
 #import model.scale_pos_weight__lgb_model as spw_lgb_model
 #import model.custom_bagging__lgb_model as cb_lgb_model
 
-def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,max_iter_cls=None, cls_ini_opt=[] ,enable_cls_opt = False, enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
+def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,max_iter_cls=None, cls_ini_opt=[] ,enable_cls_opt = False, enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",sesgo=0.15,random_state=42,url=None,print_consola=True):
     start = time.time()
-        
+    
+    if url is not None:
+        hg.validar_directorio(url)      
+    
     params.update({"metric":metric})
     params.update({"seed":random_state})
     params.update({"objective":'binary'})
@@ -105,7 +108,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             
             sesgo_var = {"COLUMN":COLUMN,"DIFF":SESGO,"F1_TRAIN":f1_train,"F1_TEST":f1_test }
             
-            if SESGO > 0.15:
+            if SESGO > sesgo:
                 list_cls_ini.remove(COLUMN)
                 sesgo_var["SESGO"]=True
                 sesgo_var["IMPROVEMENT"]=False
@@ -120,7 +123,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             print(sesgo_var)     
             list_sesgo.append(sesgo_var)
             
-            
+        
         g.save_json(list_sesgo,url+"/resumen_cls_sesgo.json")
         g.save_json(list_cls_ini,url+"/list_cls_sin_sesgo.json")           
 
